agentle.agents.exceptions.stop\_agent\_error
============================================

.. automodule:: agentle.agents.exceptions.stop_agent_error

   
   .. rubric:: Exceptions

   .. autosummary::
   
      StopAgentError
   